<CsoundSynthesizer>
<CsOptions>
-m128 ;reduce console printout
</CsOptions>
<CsInstruments>

sr = 44100
ksmps = 32
nchnls = 2
0dbfs = 1

/* as this program is now quite complex,
it is better for performance to use chnget/chnset
instead of invalue/outvalue. main difference is that 
the channels should be declared (see below) */

;decloare software channels
 ;input from gui
chn_k "which", 1
chn_k "threshdb", 1
chn_k "mintime", 1
chn_k "on_pvspitch", 1
chn_k "on_ptrack", 1
chn_k "master_vol", 1
 ;output to gui
chn_k "in", 2
chn_k "in_over", 2
chn_k "rms", 2
chn_k "pvspitchfreq", 2
chn_k "ptrackfreq", 2
chn_k "out_L", 2
chn_k "out_L_over", 2
chn_k "out_R", 2
chn_k "out_R_over", 2


;user defined opcode (UDO) for nicer signal view
opcode CsQtMeter, 0, SSak
 S_chan_sig, S_chan_over, aSig, kTrig	xin
 iDbRange = 50 ;shows 50 dB
 iHoldTim = 1 ;seconds to "hold the red light"
 kOn init 0
 kTim init 0
 kStart init 0
 kEnd init 0
 kMax max_k aSig, kTrig, 1
 if kTrig == 1 then
  chnset (iDbRange + dbfsamp(kMax)) / iDbRange, S_chan_sig
  if kOn == 0 && kMax > 1 then
   kTim = 0
   kEnd = iHoldTim
   chnset k(1), S_chan_over
   kOn = 1
  endif
  if kOn == 1 && kTim > kEnd then
   chnset k(0), S_chan_over
   kOn =	0
  endif
 endif
 kTim += ksmps/sr
endop

;load "fox.wav" and "Viola.aiff" into buffers (function tables)
giFox ftgen 0, 0, 0, 1, "fox.wav", 0, 0, 0
giViola ftgen 0, 0, 0, 1, "Viola.aiff", 0, 0, 0


instr ChooseAudio

 ;0 = live input, 1 = fox, 2 = viola
 kWhich chnget "which"
 
 ;different inputs
 aMic inch 1
 aFox poscil 1, 1/filelen("fox.wav"), giFox
 aViola poscil 1, 1/filelen("Viola.aiff"), giViola
 
 ;write one of them as global audio 
 if kWhich == 0 then
  gaIn = aMic
 elseif kWhich == 1 then
  gaIn = aFox
 else
  gaIn = aViola
 endif
 
 ;soft output
 out gaIn/10, gaIn/10

 ;show input
 gkTrigDisp metro 10
 CsQtMeter "in", "in_over", gaIn, gkTrigDisp 

endin
schedule "ChooseAudio", 0, 99999

instr AnalyzeAndTrigger

 ;settings for FFT
 iFFTsize = 1024 ;depending on the input
 iOverlap = iFFTsize / 4
 iWinSize = iFFTsize
 iWinType = 1 ;von Hann
 
 ;FFT (resulting in a f-signal
 fInput pvsanal gaIn, iFFTsize, iOverlap, iWinSize, iWinType
 
 ;continuous pitch analysis with different opcodes
 kFreqPvspitch, kAmpPvspitch pvspitch fInput, 0.01
 kFreqPtrack, kDbPtrack ptrack gaIn, 1024
 
 ;checkboxes to activate the different analyzers
 kOnPvspitch chnget "on_pvspitch"
 kOnPtrack chnget "on_ptrack"
 
 ;limit frequencies to avoid 0 Hz
 kFreqPvspitch limit kFreqPvspitch, 20, 10000
 kFreqPtrack limit kFreqPtrack, 20, 10000
 
 ;global volume
 gkGlobVolDb chnget "master_vol"
 gkGlobVolDb port gkGlobVolDb, .1
 
 ;look for threshold crossing and trigger instrument
 kThreshDb chnget "threshdb"
 kThresh = ampdb(kThreshDb)
 kMinTime chnget "mintime"
 kPause init 0 ;sec
 kPreviousRms init 0
 kRms rms gaIn
 chnset dbamp(kRms), "rms"
 if kRms > kThresh && kPreviousRms <= kThresh && kPause <= 0 then
  if kOnPvspitch == 1 then
   event "i", "Beep", 0, random:k(1,6), kFreqPvspitch, dbamp(kAmpPvspitch)
   chnset kFreqPvspitch, "pvspitchfreq"
  endif
  if kOnPtrack == 1 then
   event "i", "Beep", 0, random:k(1,6), kFreqPtrack, kDbPtrack
   chnset kFreqPtrack, "ptrackfreq"
  endif
  kPause = kMinTime
 endif
 kPause -= ksmps/sr ;count backwards
 kPreviousRms = kRms
 
endin
schedule "AnalyzeAndTrigger", 0, 99999


instr Beep

 iFreq = p4
 iAmp = ampdb(p5)
 iQ = p3 * 500

 aImp mpulse iAmp, p3
 aFilt mode aImp, iFreq, iQ

 aEnv linen aFilt*ampdb(gkGlobVolDb), 0.003, p3, p3/2 
 out aEnv, aEnv

endin

instr Monitor

 aL, aR monitor
 CsQtMeter "out_L", "out_L_over", aL, gkTrigDisp
 CsQtMeter "out_R", "out_R_over", aR, gkTrigDisp

endin
schedule "Monitor", 0, 99999


</CsInstruments>
<CsScore>

</CsScore>
</CsoundSynthesizer>
<bsbPanel>
 <label>Widgets</label>
 <objectName/>
 <x>648</x>
 <y>210</y>
 <width>779</width>
 <height>453</height>
 <visible>true</visible>
 <uuid/>
 <bgcolor mode="background">
  <r>230</r>
  <g>181</g>
  <b>107</b>
 </bgcolor>
 <bsbObject type="BSBDropdown" version="2">
  <objectName>which</objectName>
  <x>37</x>
  <y>51</y>
  <width>80</width>
  <height>30</height>
  <uuid>{f1359ce0-80eb-4e01-a924-8ed1ff9b9fce}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <bsbDropdownItemList>
   <bsbDropdownItem>
    <name>live input</name>
    <value>0</value>
    <stringvalue/>
   </bsbDropdownItem>
   <bsbDropdownItem>
    <name>fox</name>
    <value>1</value>
    <stringvalue/>
   </bsbDropdownItem>
   <bsbDropdownItem>
    <name>viola</name>
    <value>2</value>
    <stringvalue/>
   </bsbDropdownItem>
  </bsbDropdownItemList>
  <selectedIndex>1</selectedIndex>
  <randomizable group="0">false</randomizable>
 </bsbObject>
 <bsbObject type="BSBLabel" version="2">
  <objectName/>
  <x>23</x>
  <y>18</y>
  <width>124</width>
  <height>30</height>
  <uuid>{dd2c7398-dda0-47e9-86db-d45a558a5fe0}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>Choose Input</label>
  <alignment>left</alignment>
  <font>sans</font>
  <fontsize>20</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject type="BSBController" version="2">
  <objectName>in</objectName>
  <x>176</x>
  <y>34</y>
  <width>400</width>
  <height>30</height>
  <uuid>{e53212e6-26b1-4255-8dd1-29982a5f376d}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>in</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>0.77995715</xValue>
  <yValue>0.77995715</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject type="BSBController" version="2">
  <objectName>in_over</objectName>
  <x>576</x>
  <y>34</y>
  <width>30</width>
  <height>30</height>
  <uuid>{1ac98e63-ff22-42c2-b9b4-211a3387ff55}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>in_over</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>0.00000000</xValue>
  <yValue>0.00000000</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>196</r>
   <g>14</g>
   <b>12</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject type="BSBController" version="2">
  <objectName>out_L</objectName>
  <x>167</x>
  <y>309</y>
  <width>400</width>
  <height>30</height>
  <uuid>{ac88662d-99ed-4d4c-8806-63932bcef9ee}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>out_L</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>0.83009979</xValue>
  <yValue>0.83009979</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject type="BSBController" version="2">
  <objectName>out_L_over</objectName>
  <x>567</x>
  <y>309</y>
  <width>30</width>
  <height>30</height>
  <uuid>{222a8781-08d7-4dc5-910b-7474b945eb31}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>out_L_over</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>0.00000000</xValue>
  <yValue>0.00000000</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>196</r>
   <g>14</g>
   <b>12</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject type="BSBController" version="2">
  <objectName>out_R</objectName>
  <x>167</x>
  <y>345</y>
  <width>400</width>
  <height>30</height>
  <uuid>{69adc61c-b7a4-4cc3-8d73-8089cec5bd22}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>out_R</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>0.83009979</xValue>
  <yValue>0.83009979</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject type="BSBController" version="2">
  <objectName>out_R_over</objectName>
  <x>567</x>
  <y>345</y>
  <width>30</width>
  <height>30</height>
  <uuid>{32be6800-d838-404e-8bf0-f2ccdd47b0f3}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>out_R_over</objectName2>
  <xMin>0.00000000</xMin>
  <xMax>1.00000000</xMax>
  <yMin>0.00000000</yMin>
  <yMax>1.00000000</yMax>
  <xValue>0.00000000</xValue>
  <yValue>0.00000000</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>196</r>
   <g>14</g>
   <b>12</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject type="BSBKnob" version="2">
  <objectName>master_vol</objectName>
  <x>39</x>
  <y>95</y>
  <width>80</width>
  <height>80</height>
  <uuid>{ef74c409-c517-49bc-a007-5d751c56f9eb}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <minimum>-30.00000000</minimum>
  <maximum>30.00000000</maximum>
  <value>-15.60000000</value>
  <mode>lin</mode>
  <mouseControl act="jump">continuous</mouseControl>
  <resolution>0.01000000</resolution>
  <randomizable group="0">false</randomizable>
 </bsbObject>
 <bsbObject type="BSBLabel" version="2">
  <objectName/>
  <x>8</x>
  <y>178</y>
  <width>140</width>
  <height>34</height>
  <uuid>{d263a5e4-d3d3-4cf1-af94-434ad2ff9ec4}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>Volume</label>
  <alignment>center</alignment>
  <font>sans</font>
  <fontsize>20</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject type="BSBLabel" version="2">
  <objectName/>
  <x>623</x>
  <y>119</y>
  <width>150</width>
  <height>33</height>
  <uuid>{35923aa0-f82d-4e4d-9677-7bd04f1ccfba}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>Threshold (dB)</label>
  <alignment>left</alignment>
  <font>sans</font>
  <fontsize>20</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject type="BSBLabel" version="2">
  <objectName/>
  <x>625</x>
  <y>36</y>
  <width>150</width>
  <height>30</height>
  <uuid>{728133ce-2bb8-4937-8cec-6278501ad693}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>signal level (dB)</label>
  <alignment>left</alignment>
  <font>sans</font>
  <fontsize>20</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject type="BSBController" version="2">
  <objectName>rms</objectName>
  <x>175</x>
  <y>75</y>
  <width>400</width>
  <height>30</height>
  <uuid>{d022b967-17ed-48b1-adba-035cf453f627}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <objectName2>rms</objectName2>
  <xMin>-50.00000000</xMin>
  <xMax>0.00000000</xMax>
  <yMin>-50.00000000</yMin>
  <yMax>0.00000000</yMax>
  <xValue>-19.83288267</xValue>
  <yValue>-19.83288267</yValue>
  <type>fill</type>
  <pointsize>1</pointsize>
  <fadeSpeed>0.00000000</fadeSpeed>
  <mouseControl act="press">jump</mouseControl>
  <color>
   <r>0</r>
   <g>234</g>
   <b>0</b>
  </color>
  <randomizable mode="both" group="0">false</randomizable>
  <bgcolor>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </bgcolor>
 </bsbObject>
 <bsbObject type="BSBLabel" version="2">
  <objectName/>
  <x>624</x>
  <y>77</y>
  <width>150</width>
  <height>30</height>
  <uuid>{42d3e574-6245-490e-bd31-427b0f1dfa0d}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>rms level (dB)</label>
  <alignment>left</alignment>
  <font>sans</font>
  <fontsize>20</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject type="BSBHSlider" version="2">
  <objectName>threshdb</objectName>
  <x>176</x>
  <y>120</y>
  <width>370</width>
  <height>30</height>
  <uuid>{8267838d-05bb-4e26-86c2-e8c5407b4293}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <minimum>-50.00000000</minimum>
  <maximum>0.00000000</maximum>
  <value>-19.45945946</value>
  <mode>lin</mode>
  <mouseControl act="jump">continuous</mouseControl>
  <resolution>-1.00000000</resolution>
  <randomizable group="0">false</randomizable>
 </bsbObject>
 <bsbObject type="BSBScrollNumber" version="2">
  <objectName>threshdb</objectName>
  <x>552</x>
  <y>120</y>
  <width>51</width>
  <height>32</height>
  <uuid>{7774a0a3-ed5e-4c6c-a843-9a2a5f1b79d1}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <alignment>right</alignment>
  <font>sans</font>
  <fontsize>18</fontsize>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="background">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <value>-19.45945946</value>
  <resolution>1.00000000</resolution>
  <minimum>-999999999999.00000000</minimum>
  <maximum>999999999999.00000000</maximum>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
  <randomizable group="0">false</randomizable>
  <mouseControl act=""/>
 </bsbObject>
 <bsbObject type="BSBLabel" version="2">
  <objectName/>
  <x>176</x>
  <y>204</y>
  <width>97</width>
  <height>32</height>
  <uuid>{17e1453c-98e7-48b5-a35a-4174faf6868b}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>pvspitch</label>
  <alignment>center</alignment>
  <font>sans</font>
  <fontsize>20</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject type="BSBLabel" version="2">
  <objectName/>
  <x>292</x>
  <y>203</y>
  <width>73</width>
  <height>33</height>
  <uuid>{c7c8c512-d3bc-4c62-9a04-08af079db6ff}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>ptrack</label>
  <alignment>center</alignment>
  <font>sans</font>
  <fontsize>20</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject type="BSBCheckBox" version="2">
  <objectName>on_pvspitch</objectName>
  <x>225</x>
  <y>244</y>
  <width>20</width>
  <height>20</height>
  <uuid>{74feb320-061e-40df-8392-7bfcd7013162}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <selected>true</selected>
  <label/>
  <pressedValue>1</pressedValue>
  <randomizable group="0">false</randomizable>
 </bsbObject>
 <bsbObject type="BSBCheckBox" version="2">
  <objectName>on_ptrack</objectName>
  <x>315</x>
  <y>243</y>
  <width>20</width>
  <height>20</height>
  <uuid>{7e4428fc-6b98-4c99-b9fd-8d0f44fcd380}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <selected>true</selected>
  <label/>
  <pressedValue>1</pressedValue>
  <randomizable group="0">false</randomizable>
 </bsbObject>
 <bsbObject type="BSBLabel" version="2">
  <objectName/>
  <x>386</x>
  <y>234</y>
  <width>150</width>
  <height>33</height>
  <uuid>{7e1bd42f-2522-4325-abfa-12a2608dd5d0}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>active tools</label>
  <alignment>left</alignment>
  <font>sans</font>
  <fontsize>20</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject type="BSBSpinBox" version="2">
  <objectName>mintime</objectName>
  <x>175</x>
  <y>163</y>
  <width>84</width>
  <height>34</height>
  <uuid>{7227600a-422e-47ec-b72d-e413fb040724}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>0</midicc>
  <alignment>right</alignment>
  <font>sans</font>
  <fontsize>20</fontsize>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <resolution>0.00100000</resolution>
  <minimum>-1e+12</minimum>
  <maximum>1e+12</maximum>
  <randomizable group="0">false</randomizable>
  <value>1</value>
 </bsbObject>
 <bsbObject type="BSBLabel" version="2">
  <objectName/>
  <x>267</x>
  <y>164</y>
  <width>507</width>
  <height>35</height>
  <uuid>{ee4a7507-c867-4dc6-a700-4a8848cb3d86}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>minimal time between two triggers (sec)</label>
  <alignment>left</alignment>
  <font>sans</font>
  <fontsize>20</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject type="BSBLabel" version="2">
  <objectName/>
  <x>385</x>
  <y>271</y>
  <width>150</width>
  <height>33</height>
  <uuid>{dff806e3-0726-40bf-b291-09f08230477b}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <label>analyzed freq</label>
  <alignment>left</alignment>
  <font>sans</font>
  <fontsize>20</fontsize>
  <precision>3</precision>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="nobackground">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <bordermode>noborder</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
 </bsbObject>
 <bsbObject type="BSBScrollNumber" version="2">
  <objectName>pvspitchfreq</objectName>
  <x>189</x>
  <y>267</y>
  <width>79</width>
  <height>33</height>
  <uuid>{5b3a4343-bd63-4a72-9470-ff0cce8be2d2}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <alignment>right</alignment>
  <font>sans</font>
  <fontsize>18</fontsize>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="background">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <value>94.73597606</value>
  <resolution>0.01000000</resolution>
  <minimum>-999999999999.00000000</minimum>
  <maximum>999999999999.00000000</maximum>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
  <randomizable group="0">false</randomizable>
  <mouseControl act=""/>
 </bsbObject>
 <bsbObject type="BSBScrollNumber" version="2">
  <objectName>ptrackfreq</objectName>
  <x>284</x>
  <y>267</y>
  <width>79</width>
  <height>33</height>
  <uuid>{b06306c6-0f73-4a00-b7e1-b751c09f514e}</uuid>
  <visible>true</visible>
  <midichan>0</midichan>
  <midicc>-3</midicc>
  <alignment>right</alignment>
  <font>sans</font>
  <fontsize>18</fontsize>
  <color>
   <r>0</r>
   <g>0</g>
   <b>0</b>
  </color>
  <bgcolor mode="background">
   <r>255</r>
   <g>255</g>
   <b>255</b>
  </bgcolor>
  <value>2762.58606973</value>
  <resolution>0.01000000</resolution>
  <minimum>-999999999999.00000000</minimum>
  <maximum>999999999999.00000000</maximum>
  <bordermode>border</bordermode>
  <borderradius>1</borderradius>
  <borderwidth>1</borderwidth>
  <randomizable group="0">false</randomizable>
  <mouseControl act=""/>
 </bsbObject>
</bsbPanel>
<bsbPresets>
</bsbPresets>
